@@ -693,7 +693,8 @@ def generate(process):
         for stateName, inputSymbols in process.mapping.viewitems():
             if stateName != 'START':
                 for i in inputSymbols:
-                    if inputSignal in i.inputlist:
+                    if inputSignal.lower() in [inp.lower() for
+                                               inp in i.inputlist]:
                         mapping[inputSignal][stateName] = i
 
     # Generate the TASTE template
