@@ -1005,13 +1005,14 @@ class sdlScc_AST:
                 # get input name and parameters
                 for inputname in [c for c in child.getChildren() if
                         c.toString() != 'PARAMS']:
-                    if inputname.toString().lower() not in [
-                            inpSig.lower() for inpSig in
-                            self.process.inputSignals]:
+                    for inpSig in self.process.inputSignals.viewkeys():
+                        if inpSig.lower() == inputname.toString().lower():
+                            i.inputlist[inpSig] = -1
+                            break
+                    else:
                         warnings.append('Input signal not declared: '
                                 + inputname.toString() +
                                 ' (line ' + str(i.line) + ')')
-                    i.inputlist[inputname.toString()] = -1
                 for inputparam in [c.getChildren() for c in
                         child.getChildren() if c.toString() == 'PARAMS']:
                     i.parameters = [p.toString() for p in inputparam]
@@ -1026,6 +1027,8 @@ class sdlScc_AST:
                 errors = [[e, i.absCoordinates] for e in errors]
                 warnings = [[w, i.absCoordinates] for w in warnings]
             elif child.type == ASTERISK:
+                # Asterisk means: all inputs not processed explicitely
+                # -> FIXME, below is incorrect
                 i.inputString = getInputString(child)
                 i.line = child.getLine()
                 i.charPositionInLine = child.getCharPositionInLine()
@@ -1043,7 +1046,7 @@ class sdlScc_AST:
                 # The reference is an index to process.transitions table
                 self.process.transitions.append(transition)
                 for inp in i.inputlist:
-                    i.inputlist[inp]=len(self.process.transitions)-1
+                    i.inputlist[inp]=len(self.process.transitions) - 1
             elif child.type == COMMENT:
                 i.comment, _, __ = self.end(child)
             elif child.type == HYPERLINK:
